<?php

require_once __DIR__ . '/utils/AuthPlugins.php';
require_once __DIR__ . '/db/Helpers.php';
require_once __DIR__ . '/utils/CSS.php';

function generate_link($fileId, $sampleMobile)
{
    $id = sanitize_text_field($fileId);
    $phone = sanitize_text_field($sampleMobile);

    $auth_plugin = get_auth_plugin_object();
    $user_phone = "";

    if ($auth_plugin['key'] == "test") {
        $user_phone = $phone;
    }

    if (have_meta_key()) {
        $user_phone = verify_mobile(have_meta_key());
    }

    if ($id) {
        $options = get_option('vidprotect_plugin_options');
        $bodydata = [
            'fileId' => $id,
        ];

        if (!empty($user_phone)) {
            $bodydata['mobileNumber'] = $user_phone;
        }

        if (!empty($user_phone) && !isIranianMobile($user_phone)) {
            $MAX_LEN = 39;

            if (strlen($user_phone) > $MAX_LEN) {
                $user_phone = str_replace(' ', '', substr($user_phone, 0, $MAX_LEN));
            }

            $bodydata['extraWatermark'] = $user_phone;
            unset($bodydata['mobileNumber']);
        }

        $postdata = http_build_query($bodydata);

        $opts = [
            "http" => [
                "method" => "POST",
                "header" => "api_key: " . $options["api_key"] . "\r\n" .
                    "secret_key: " . $options["secret_key"] . "\r\n" .
                    "Content-Type: application/x-www-form-urlencoded",
                'content' => $postdata
            ]
        ];
        $context = stream_context_create($opts);
        $request = file_get_contents(BACK_URL . "generate/link", false, $context);
        return @json_decode($request);
    }

    return ["url" => ""];
}

function generate_link_example()
{
    if (isset($_GET['api-type']) && $_GET['api-type'] == 'vidprotect') {
        wp_send_json(generate_link($_GET['id'], $_GET['phone']));
    }
}


function add_vidprotect_scripts()
{
    wp_enqueue_style('vidprotect_styles', plugins_url('styles.css', __DIR__ . '/public/css/styles.css'), '', '1.0');
    wp_enqueue_script('vidprotect_script', plugins_url('UserScript.js', __DIR__ . '/public/scripts/UserScript.js'), '', '1.0');
    wp_enqueue_script('vidprotect_script', plugins_url('AdminScript.js', __DIR__ . '/public/scripts/AdminScript.js'), '', '1.0');
}

function add_vidprotect_admin_scripts()
{
    wp_enqueue_script('vidprotect_admin_script', plugins_url('AdminScript.js', __DIR__ . '/public/scripts/AdminScript.js'), '', '1.0');
}

function vidprotect_shortcode_func($atts)
{
    ob_start();
    $auth_plugin = get_auth_plugin_object();

    if ($auth_plugin['key'] == "test") {
        ?>
      <a class="<?php echo $atts['class']; ?> vidprotect-link"
         href="#vidprotect=<?php echo $atts['id']; ?>"><?php echo $atts['title'] ?: "مشاهده ویدیو"; ?>
      </a>
        <?php
    } else {
        $video_link = generate_link($atts['id'], '')->url;
        ?>

        <?php if (isset($video_link)) : ?>
        <iframe class="vidprotect-ready"
                src="<?php echo $video_link ?>"
                allow="encrypted-media *; fullscreen"></iframe>
        <?php endif; ?>

        <?php if (!isset($video_link)) : ?>
        <p>خطای ناشناخته ای به وجود آمده است</p>
        <?php endif; ?>

        <?php
    }

    return ob_get_clean();
}

function vidprotect_add_custom_css()
{
    $options = get_option('vidprotect_plugin_options');

    echo "<style id='vidprotect-custom-css'>\n";
    echo empty($options['iframe_css']) ? get_default_iframe_css() : $options['iframe_css'];
    echo "\n</style>";
}