<?php

require_once __DIR__ . '/../utils/AuthPlugins.php';
require_once __DIR__ . '/../utils/RestApi.php';
require_once __DIR__ . '/../utils/File.php';
require_once __DIR__ . '/../utils/CSS.php';

function vidprotect_add_settings_page()
{
    add_menu_page('ویدپروتکت', 'ویدپروتکت', 'manage_options', 'vidprotect-plugin', 'vidprotect_render_plugin_settings_page', plugins_url('../public/logo.png', __FILE__), 10);
}

function vidprotect_register_settings()
{
    register_setting('vidprotect_plugin_options', 'vidprotect_plugin_options', 'vidprotect_plugin_options_validate');
    $options = get_option('vidprotect_plugin_options');

    register_component(
        [
            ['vidprotect_plugin_setting_api_key', 'API KEY', 'api_key'],
            ['vidprotect_plugin_setting_secret_key', 'SECRET KEY', 'secret_key']
        ],
        $options,
        'api_settings',
        'vidprotect_plugin_section_key_settings',
        'مدیریت کلید های دسترسی'
    );

    register_component(
        [
            ['vidprotect_plugin_setting_auth_plugin', 'OTP Plugin', 'auth_plugin'],
            $options['auth_plugin'] != "custom" ? [] : ['vidprotect_plugin_setting_auth_meta_key', 'Custom Auth Meta Key', 'auth_meta_key']
        ],
        $options,
        'auth_settings',
        'vidprotect_plugin_section_mobile_otp_settings',
        'مدیریت واترمارک (شماره موبایل، ایمیل، آیدی کاربر، و...)'
    );

    register_component(
        [
            ['vidprotect_plugin_setting_iframe_css', 'Custom Iframe CSS', 'iframe_css'],
        ],
        $options,
        'other_settings',
        'vidprotect_plugin_section_other_settings',
        'تنظیمات پیشرفته'
    );
}

function register_component($fields, $options, $settingName, $callback, $title)
{
    $ignore_list = ["api_settings"];

    if (!isUserLogged() && !in_array($settingName, $ignore_list)) {
        return;
    }

    add_settings_section($settingName, $title, $callback, 'vidprotect_plugin');

    for ($i = 0; $i < count($fields); $i++) {
        if (empty($fields[$i][0])) {
            continue;
        }

        add_settings_field(
            $fields[$i][0],
            $fields[$i][1],
            'vidprotect_plugin_setting_input',
            'vidprotect_plugin',
            $settingName,
            ['id' => $fields[$i][0], 'name' => $fields[$i][2], 'options' => $options]
        );
    }
}

function vidprotect_render_plugin_settings_page()
{
    $video = have_file();
    $verify_key_res = verify_keys();
    $tab = isset($_GET['tab']) ? $_GET['tab'] : ($video ? 'videos' : null);
    $current_page = isset($_GET['paged']) ? intval($_GET['paged']) : 1;
    $order_by_date = isset($_GET['orderByDate']) ? $_GET['orderByDate'] : "desc";
    ?>

    <?php if (!$verify_key_res['ok']) : ?>
  <div id="errorDialog"
       style="position: fixed; top: 0; left: 0; width: 100%; height: 100%; background: rgba(0, 0, 0, 0.7); justify-content: center; align-items: center; z-index: 9999;">
    <div
      style="border: none; cursor: pointer; font-size: 18px; background-color: white; color: white; padding: 20px; border-radius: 8px; box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2); position: fixed; top: 50%; left: 50%; transform: translate(-50%, -50%); z-index: 1000; width: 300px; font-family: Arial, sans-serif;">
      <h4 style="margin: 0; font-size: 18px; color: #D32F2F">خطا!</h4>
      <p style="margin: 10px 0 0; color: black"><?php echo $verify_key_res['message'] ?></p>

      <div style="text-align: left;">
        <button
          style="background-color: #66a310; color: white; border: none; padding: 8px 12px; border-radius: 5px; cursor: pointer; margin-top: 10px;"
          onclick="closeErrorDialog()">بستن
        </button>
      </div>
    </div>
  </div>
<?php endif; ?>

  <div id="helpDialog" style="background: #2c3e50 !important; margin: 3px; border-radius: 5px; padding: 5px;">
    <p onclick="closeHelpDialog()"
       style="float: left; cursor: pointer; color: white; margin-right: 7px; width: 40px; height: 40px">&#10006;</p>
    <h3 style="color: white; margin-right: 7px;">i</h3>
    <p style="color: white; margin-right: 10px;">برای نمایش ویدیو‌های خود فقط کافی است که لینک کوتاه را در هر جایی
      که خواستید قرار دهید.
      <a style="text-decoration: none !important; color: #66a310; font-weight: bold; cursor: pointer;"
         target="_blank" href="https://docs.vidprotect.ir/docs/wordpress/how-to-use">اطلاعات بیشتر</a>
    </p>
  </div>

  <nav class="nav-tab-wrapper">
      <?php if ($video) : ?>
        <a href="?page=vidprotect-plugin&tab=videos&currentPage=1"
           class="nav-tab <?php if ($tab == 'videos') : ?>nav-tab-active<?php endif; ?>">ویدیوهای من</a>
      <?php endif; ?>
    <a href="?page=vidprotect-plugin&tab=settings"
       class="nav-tab <?php if ($tab == null || $tab == 'settings') : ?>nav-tab-active<?php endif; ?>">تنظیمات</a>
  </nav>

    <?php

    switch ($tab):
        case 'videos':
            $files_list = new File($current_page, $order_by_date);
            $files_list->prepare_items();
            ?>
          <div style="padding-top: 20px; padding-right: 20px">
            <label for="sortOrder" style="font-weight: bold"> مرتب ‌سازی بر اساس تاریخ:</label>
            <select id="sortOrder" name="order" onchange="handleSortChange(this.value)">
              <option value="desc" <?php echo $_GET['orderByDate'] == 'desc' ? 'selected' : ''; ?>>نزولی (جدیدترین)
              </option>
              <option value="asc" <?php echo $_GET['orderByDate'] == 'asc' ? 'selected' : ''; ?>>صعودی (قدیمی‌ترین)
              </option>
            </select>
          </div>
          <div class="wrap">
            <div id="icon-users" class="icon32"></div>
            <div id="vidprotect-copy" class="notice notice-success" style="display:none">
              <p>متن مورد نظر کپی شد</p>
            </div>
              <?php $files_list->display(); ?>
          </div>
            <?php
            break;
        case 'settings':
        default:
            ?>
          <form action="options.php" method="post" id="vidprotect-settings-form">
              <?php
              settings_fields('vidprotect_plugin_options');
              do_settings_sections('vidprotect_plugin'); ?>

            <div id="loading-overlay"
                 style="display: none; position: fixed; top: 0; left: 0; width: 100%; height: 100%; background: rgba(0, 0, 0, 0.7); justify-content: center; align-items: center; z-index: 9999;">
              <div id="loading-spinner" style="text-align: center;">
                <img src="<?php echo plugins_url('../public/loading.svg', __FILE__); ?>" alt="Loading..." />
              </div>
            </div>

            <input name="submit" class="button button-primary" id="save-data" onclick="saveData()" type="submit"
                   value="<?php esc_attr_e('ذخیره'); ?>" />
          </form>
            <?php
            break;
    endswitch;
}

function vidprotect_plugin_options_validate($input)
{
    $newinput['api_key'] = trim($input['api_key']);
    $newinput['secret_key'] = trim($input['secret_key']);
    $newinput['iframe_css'] = trim($input['iframe_css']);
    $newinput['auth_plugin'] = trim($input['auth_plugin']);
    $newinput['auth_meta_key'] = trim($input['auth_meta_key']);

    return $newinput;
}

function vidprotect_plugin_section_key_settings()
{
    echo "<p>جهت فعال سازی پلاگین، لطفا از قسمت تنظیمات امنیتی در سابت <a href='https://vidprotect.ir/panel/settings/security-settings' style='color: #66a310; text-decoration: none;' target='_blank'>VidProtect</a> و از بخش کلید های دسترسی افزونه وردپرس (API KEY, SECRET KEY) خود را در کادر های زیر وارد کنید.</p>";
}

function vidprotect_plugin_section_other_settings()
{
    echo '<p>تغییرات پیشرفته خود را می توانید از طریق موارد پایین اعمال کنید.</p>';
}

function vidprotect_plugin_section_mobile_otp_settings()
{
    echo '<p>برای نمایش خودکار واترمارک به دانشجو شامل اطلاعات (موبایل دانشجو، ایمیل، آیدی کاربر، و...) می توانید با استفاده از گزینه های زیر اقدام به انتخاب پلاگین احراز هویت خود کنید. <a href="https://docs.vidprotect.ir/docs/wordpress/watermark#واترمارک-سفارشی" style="color: #66a310; text-decoration: none;" target="_blank">اطلاعات بیشتر</a></p>';
}

function isUserLogged()
{
    $options = get_option('vidprotect_plugin_options');
    return !(empty($options['secret_key']) || empty($options['api_key']));
}

function vidprotect_plugin_setting_input($args)
{
    $api_key = isset($args['options']['api_key']) ? $args['options']['api_key'] : '';
    $secret_key = isset($args['options']['secret_key']) ? $args['options']['secret_key'] : '';
    $input_type = "text";

    if (empty($api_key) || empty($secret_key)) {
        if ($args['name'] !== 'api_key' && $args['name'] !== 'secret_key') {
            return;
        }
    }

    if ($args['name'] == 'auth_plugin') {
        $auth_plugin_value = !empty($args['options'][$args['name']]) ? $args['options'][$args['name']] : '';

        $select_tag = [
            "<select id='",
            $args['id'],
            "' name='vidprotect_plugin_options[",
            $args['name'],
            "]' class='vidprotect-setting' >"
        ];

        foreach (get_supported_auth_plugins() as $plugin) {
            $select_tag[] = "<option value='" . $plugin['key'] . "' " . selected($auth_plugin_value, $plugin['key'], false) . " >" . $plugin['title'] . "</option>";
        }

        $select_tag[] = "</select>";

        echo implode("", $select_tag);
        return;
    }

    if (
        $args['name'] == 'auth_meta_key' &&
        isset($args['options']['auth_plugin']) &&
        $args['options']['auth_plugin'] == 'custom'
    ) {
        echo '<p style="padding-bottom: 10px">در صورت استفاده از پلاگین های دیگر جهت ثبت نام، نام فیلد را در کادر زیر بنویسید و از صحت آن اطمینان حاصل کنید.</p>';
    } else if ($args['name'] == 'auth_meta_key') {
        // Skip rendering if auth_plugin is not custom
        return;
    }

    if ($args['name'] == 'secret_key') {
        $input_type = 'password';
    }

    if ($args['name'] == 'api_key') {
        $input_type = 'text';
    }

    if ($args['name'] == 'iframe_css') {
        echo '<p>کد CSS دلخواه خود را برای کلاس <code>.vidprotect-ready</code> در کادر زیر وارد کنید. <a href="https://docs.vidprotect.ir/docs/wordpress/custom-iframe-css" style="color: #66a310; text-decoration: none;" target="_blank">اطلاعات بیشتر</a> </p><br/>';
        $textarea_tag = [
            "<textarea id='",
            $args['id'],
            "' name='vidprotect_plugin_options[",
            $args['name'],
            "]' class='vidprotect-setting' rows='15' cols='60' style='width: 38vh; direction: ltr; text-align: left'>"
        ];

        $value = $args['options'][$args['name']];

        if (!empty($value)) {
            $textarea_tag[] = esc_textarea($value);
        } else {
            $textarea_tag[] = get_default_iframe_css();
        }

        $textarea_tag[] = "</textarea>";

        echo implode("", $textarea_tag);
        return;
    }

    $input_tag = [
        "<input id='",
        $args['id'],
        "' name='vidprotect_plugin_options[",
        $args['name'],
        "]' type='$input_type' class='vidprotect-setting' value='"
    ];

    if (esc_attr(($args['options'] && array_key_exists($args['name'], $args['options'])))) {
        $input_tag[] = $args['options'][$args['name']];
    }

    $input_tag[] = "' style=' width: 38vh; direction: ltr; text-align: left' />";

    echo implode("", $input_tag);
}