<?php

require_once __DIR__ . '/RestApi.php';

if (!class_exists('WP_List_Table')) {
    require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}

class File extends WP_List_Table
{
    protected $total_items = 0;
    protected $current_page = 1;
    protected $order_by_date = "desc";

    public function __construct($current_page, $order_by_date)
    {
        parent::__construct();
        $this->current_page = $current_page;
        $this->order_by_date = $order_by_date;
    }

    public function prepare_items()
    {
        $columns = $this->get_columns();
        $data = $this->table_data();

        $per_page = 9;
        $total_items = $this->total_items;

        $this->_column_headers = array($columns);
        $this->items = $data;

        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page' => $per_page,
            'total_pages' => ceil($total_items / $per_page),
            'current_page' => $this->current_page,
        ));
    }

    /**
     * Override the parent columns method. Defines the columns to use in your listing table
     *
     * @return Array
     */
    public function get_columns()
    {
        $columns = array(
            'image' => '<p style="text-align:center">تصویر<p>',
            'title' => '<p style="text-align:center">عنوان<p>',
            'short_code' => '<p style="text-align:center">لینک<p>'
        );

        return $columns;
    }

    /**
     * Define what data to show on each column of the table
     *
     * @param Array $item Data
     * @param String $column_name - Current column name
     *
     * @return Mixed
     */
    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'title':
            case 'short_code':
            case 'image':
                return $item[$column_name] ?: '---';
            default:
                return print_r($item, true);
        }
    }

    /**
     * Get the table data
     *
     * @return Array
     */
    private function table_data()
    {
        $response = get_files_from_api($this->current_page, $this->order_by_date);

        $this->total_items = $response->totalResults;
        $data = [];

        foreach ($response->results as $el) {
            $short_code = '[vidprotect id="' . $el->_id . '"]';
            $data[] = [
                'image' => '<div style="display: flex; justify-content: center;"><img style="margin: auto; max-height: 75px; border-radius: 5%; -webkit-filter: drop-shadow(5px 5px 5px #222); filter: drop-shadow(5px 5px 5px #222);" src="' . $el->thumbnail . '" /> </div>',
                'title' => '<p style="text-align:center">' . $el->title . '<p>',
                'short_code' => '<span style="cursor: pointer; display: table; margin: 0 auto;" onclick="copyVidProtectLink(\'' . htmlspecialchars($short_code) . '\')">' . $short_code . '</span>'
            ];
        }

        return $data;
    }

    /**
     * Display pagination for the table
     */
    public function display_pagination()
    {
        $total_pages = $this->get_pagination_arg('total_pages');
        $current_page = $this->get_pagination_arg('current_page');

        if ($total_pages > 1) {
            for ($i = 1; $i <= $total_pages; $i++) {
                $active = $i == $current_page ? 'style="font-weight:bold;"' : '';
                echo '<a href="?page=vidprotect-plugin&tab=videos&paged=' . $i . '" ' . $active . '>' . $i . '</a> ';
            }
        }
    }
}
